#!/bin/sh

LANG=C
set -u
#
# dnsbl-check-standalone.sh
#
# By Damon Tajeddini (dta)
# # 10.03.2009
# 
# als nagios-plugin rbe@lihas.de Sep. 2009
#
#MAIL_RCPT="lihas@lihas.de"

OK=0
WARNING=1
CRITICAL=2
UNKNOWN=3

DNSBLlist=`grep -v ^# <<!
cbl.abuseat.org
dnsbl.ahbl.org
ircbl.ahbl.org
virbl.dnsbl.bit.nl
blackholes.five-ten-sg.com
dnsbl.inps.de
ix.dnsbl.manitu.net
no-more-funn.moensted.dk
combined.njabl.org
dnsbl.njabl.org
dnsbl.sorbs.net
bl.spamcannibal.org
bl.spamcop.net
sbl.spamhaus.org
xbl.spamhaus.org
pbl.spamhaus.org
dnsbl-1.uceprotect.net
# dnsbl-2.uceprotect.net
# dnsbl-3.uceprotect.net
!`

# reverse IP address bytes
convertIP()
{
 set `IFS=".";echo $1`
 echo $4.$3.$2.$1
}

usage()
{
 echo "Usage: $0 [-H &lt;host&gt;|-p]"
 echo " -H IP address to check"
 echo " -F FQDN to check"
 echo " -p Print list of DNSBLs"
 exit 3
}

# Checks the IP with list of DNSBL servers
check()
{
 ret_value=$OK
 blacklists=""
 for i in $DNSBLlist
 do
   if dig $ip_arpa.$i +short | grep -q "^127.0.0."
   then
     ret_value=$CRITICAL
     blacklists+="$i,"
   fi
 done
 blacklists=${blacklists%,}
 host_name=`host $ip | head -n 1 | awk '{print $NF}'`
 host_name=${host_name%.}
 #host_name=`echo $host_name`
 if [ "$ret_value" = "$OK" ]; then 
   echo -e "DNSBL OK for $ip ($host_name)\n" 
 else
   echo -e "DNSBL FAILDED for $ip ($host_name)\nblacklisted on: $blacklists\n"
 fi
 exit $ret_value
} # check

case $1 in
 -H)
 if [ -z "$2" ]; then
   echo "ip address missing"
   exit $UNKNOWN
 fi
 ip=$2
 ip_arpa=`convertIP $ip`
 check;;

 -F)
 if [ -z "$2" ]; then
   echo "hostname address missing"
   exit $UNKNOWN
 fi
 ip=`host $2  | head -1 | awk '{print $NF}'`
 $0 -H "$ip"
 ;;

 -p)
 for i in $DNSBLlist
 do
 echo $i
 done
 exit $UNKNOWN;;

 --help)
 usage
 exit;;

 *)
 if [ -z "$1" ]; then
 usage
 fi
 echo "unknown command: $1"
 exit $UNKNOWN;;
esac
